Graph
=====

.. currentmodule:: bioontologies.obograph

.. autoclass:: Graph
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Graph.default_namespace
      ~Graph.description
      ~Graph.license
      ~Graph.root
      ~Graph.title
      ~Graph.version
      ~Graph.version_iri

   .. rubric:: Methods Summary

   .. autosummary::

      ~Graph.get_alternative_ids
      ~Graph.standardize

   .. rubric:: Attributes Documentation

   .. autoattribute:: default_namespace
   .. autoattribute:: description
   .. autoattribute:: license
   .. autoattribute:: root
   .. autoattribute:: title
   .. autoattribute:: version
   .. autoattribute:: version_iri

   .. rubric:: Methods Documentation

   .. automethod:: get_alternative_ids
   .. automethod:: standardize
